import React, { useState, useEffect } from 'react';
import { Button } from '../buttons'; // Adjust the import path according to your project structure
import { Tooltip, TooltipContent, TooltipProvider, TooltipTrigger } from '../../components/tooltip';
import { setTheme, Theme } from '@graphpolaris/shared/lib/data-access/store/configSlice';
import { useAppDispatch, useConfig } from '@graphpolaris/shared/lib/data-access/store';

const ColorMode = () => {
  const config = useConfig();
  const dispatch = useAppDispatch();

  // Function to update the body class
  const applyTheme = (themeValue: string) => {
    document.body.className = themeValue;
  };

  // Update the local storage and body class whenever the theme changes
  useEffect(() => {
    if (config.theme) {
      applyTheme(config.theme);
    }
  }, [config.theme]);

  // Function to toggle the theme
  const toggleTheme = () => {
    const themes = [
      Theme.light,
      Theme.dark,
    ]
    
    const newTheme = themes[(themes.indexOf(config.theme) + 1) % themes.length];
    dispatch(setTheme(newTheme));
  };
  const iconComponent = config.theme === Theme.dark ? 'icon-[ic--baseline-dark-mode]' : 'icon-[ic--baseline-light-mode]';

  return (
    <TooltipProvider delayDuration={0}>
      <Tooltip placement={'right'}>
        <TooltipTrigger asChild>
          <Button variant="ghost" size="sm" iconComponent={iconComponent} onClick={toggleTheme} />
        </TooltipTrigger>
        <TooltipContent>
          <p>{`Switch to ${config.theme === Theme.dark ? 'light' : 'dark'}-mode`}</p>
        </TooltipContent>
      </Tooltip>
    </TooltipProvider>
  );
};

export default ColorMode;
