import React, { useState, useMemo, useEffect } from 'react';
import { VisualizationSettingsPropTypes } from '@graphpolaris/shared/lib/vis/common';
import { MapProps } from '../../mapvis';
import { Button, EntityPill, Input } from '@graphpolaris/shared/lib/components';
import { MapLayerSettingsPropTypes } from '..';

export function HeatLayerOptions({ settings, graphMetadata, updateSettings, spatialAttributes }: MapLayerSettingsPropTypes) {
  const handleCollapseToggle = (nodeType: string) => {
    settings.nodes[nodeType].collapsed = !settings.nodes[nodeType].collapsed;
    updateSettings({ nodes: settings.nodes });
  };

  return (
    <div>
      {settings?.nodes &&
        Object.keys(settings.nodes).map((nodeType) => {
          const nodeSettings = settings.nodes[nodeType];
          return (
            <div className="mt-2" key={nodeType}>
              <div className="flex items-center">
                <div className="w-3/4 mr-6 cursor-pointer" onClick={() => handleCollapseToggle(nodeType)}>
                  <EntityPill title={nodeType} />
                </div>
                <div className="w-1/2">
                  <Button
                    iconComponent={nodeSettings.hidden ? 'icon-[ic--baseline-visibility-off]' : 'icon-[ic--baseline-visibility]'}
                    variant="ghost"
                    onClick={() =>
                      updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, hidden: !nodeSettings.hidden } } })
                    }
                  />
                </div>
              </div>

              {!nodeSettings.collapsed && (
                <div>
                  <Input
                    inline
                    label="Latitude"
                    type="dropdown"
                    value={nodeSettings.lat}
                    options={[...(spatialAttributes[nodeType] || [])]}
                    disabled={!settings.node || spatialAttributes[nodeType].length < 1}
                    onChange={(val) => {
                      updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, lat: String(val) } } });
                    }}
                  />
                  <Input
                    inline
                    label="Longitude"
                    type="dropdown"
                    value={nodeSettings.lon}
                    options={[...(spatialAttributes[nodeType] || [])]}
                    disabled={!settings.node || spatialAttributes[nodeType].length < 1}
                    onChange={(val) => {
                      updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, lon: String(val) } } });
                    }}
                  />
                  <Input
                    label="Size"
                    type="slider"
                    min={0}
                    max={40}
                    step={1}
                    value={nodeSettings.size}
                    onChange={(val) => {
                      updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, size: Number(val) } } });
                    }}
                  />
                </div>
              )}
            </div>
          );
        })}
    </div>
  );
}
