import React, { useEffect, useMemo, useState } from 'react';
import ColorPicker from '@graphpolaris/shared/lib/components/colorComponents/colorPicker';
import { MapNodeOrEdgeData, MapProps } from '../../mapvis';
import { VisualizationSettingsPropTypes } from '@graphpolaris/shared/lib/vis/common';
import { EntityPill, Icon, Input } from '@graphpolaris/shared/lib/components';
import { MapLayerSettingsPropTypes } from '..';

export default function NodeOptions({ settings, graphMetadata, updateSettings, spatialAttributes }: MapLayerSettingsPropTypes) {
  const handleCollapseToggle = (nodeType: string) => {
    settings.nodes[nodeType].collapsed = !settings.nodes[nodeType].collapsed;
    updateSettings({ nodes: settings.nodes });
  };

  return (
    <div>
      {settings?.nodes &&
        Object.keys(settings.nodes).map((nodeType) => {
          const nodeSettings = settings.nodes[nodeType];
          return (
            <div className="mt-2" key={nodeType}>
              <div className="flex items-center">
                <div className="w-3/4 mr-6 cursor-pointer" onClick={() => handleCollapseToggle(nodeType)}>
                  <EntityPill title={nodeType} />
                </div>
                <div className="w-1/2">
                  <ColorPicker
                    value={nodeSettings.color}
                    updateValue={(val) => {
                      updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, color: val } } });
                    }}
                  />
                </div>
              </div>

              {!nodeSettings.collapsed && (
                <div>
                  <Input
                    inline
                    label="Latitude"
                    type="dropdown"
                    value={nodeSettings.lat}
                    options={[...(spatialAttributes[nodeType] || [])]}
                    disabled={!settings.node || spatialAttributes[nodeType].length < 1}
                    onChange={(val) => {
                      updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, lat: String(val) } } });
                    }}
                  />
                  <Input
                    inline
                    label="Longitude"
                    type="dropdown"
                    value={nodeSettings.lon}
                    options={[...(spatialAttributes[nodeType] || [])]}
                    disabled={!settings.node || spatialAttributes[nodeType].length < 1}
                    onChange={(val) => {
                      updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, lon: String(val) } } });
                    }}
                  />

                  <div className="ml-2">
                    <div className="flex items-center gap-1">
                      <Icon component="icon-[ic--baseline-subdirectory-arrow-right]" size={16} color="text-secondary-300" />

                      <Input
                        label="Hidden"
                        type="boolean"
                        value={nodeSettings.hidden}
                        onChange={(val) => {
                          updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, hidden: val } } });
                        }}
                      />
                    </div>

                    <div>
                      <div className="flex items-center gap-1">
                        <Icon component="icon-[ic--baseline-subdirectory-arrow-right]" size={16} color="text-secondary-300" />
                        <span>Radius</span>
                      </div>
                      <Input
                        label="Fixed"
                        type="boolean"
                        value={nodeSettings.fixed}
                        onChange={(val) => {
                          updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, fixed: val } } });
                        }}
                      />
                      {!settings?.[nodeType]?.fixed ? (
                        <div>
                          <Input
                            label="Based on"
                            type="dropdown"
                            size="xs"
                            options={spatialAttributes[nodeType]}
                            value={nodeSettings.sizeAttribute}
                            onChange={(val) => {
                              updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, sizeAttribute: String(val) } } });
                            }}
                          />
                          <div className="flex">
                            <Input
                              type="number"
                              label="min"
                              size="xs"
                              value={nodeSettings.min}
                              onChange={(val) => {
                                updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, min: Number(val) } } });
                              }}
                            />
                            <Input
                              type="number"
                              label="max"
                              size="xs"
                              value={nodeSettings.max}
                              onChange={(val) => {
                                updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, max: Number(val) } } });
                              }}
                            />
                          </div>
                        </div>
                      ) : (
                        <div>
                          <Input
                            type="slider"
                            label="Width"
                            min={0}
                            max={10}
                            step={0.5}
                            value={nodeSettings.radius}
                            onChange={(val) => {
                              updateSettings({ nodes: { ...settings.nodes, [nodeType]: { ...nodeSettings, radius: Number(val) } } });
                            }}
                          />
                        </div>
                      )}
                    </div>
                  </div>
                </div>
              )}
            </div>
          );
        })}
    </div>
  );
}
